pub fn audio_format_from_path(path: &Path) -> Option<AudioFormat>Expand description
Returns the selectable audio output format represented by a path.
pub fn audio_format_from_path(path: &Path) -> Option<AudioFormat>Returns the selectable audio output format represented by a path.