start_conversion

Function start_conversion 

pub fn start_conversion(
    request: &ConversionRequest,
) -> Result<Receiver<OperationEvent>, ConversionError>
Validates a request and starts its conversion on a background thread.

Process startup and ffmpeg failures are reported through the returned event stream as OperationEvent::Finished.