pub fn video_format_from_path(path: &Path) -> Option<VideoFormat>Expand description
Returns the selectable video output format represented by a path.
pub fn video_format_from_path(path: &Path) -> Option<VideoFormat>Returns the selectable video output format represented by a path.