pub fn start_conversion(
request: &ConversionRequest,
) -> Result<Receiver<OperationEvent>, ConversionError>Expand description
Validates a request and starts its conversion on a background thread.
Process startup and ffmpeg failures are reported through the returned event
stream as OperationEvent::Finished.